Welcome to PyRemoteData’s documentation! — PyRemoteData 0.0.38 documentation

Skip to content

The documentation is a work in progress!

# Welcome to PyRemoteData’s documentation!

PyRemoteData is a Python package for downloading and managing remote data on servers supporting the SFTP protocol.

It has primarily been developed to facilitate high-throughput data transfer in high-bandwidth/high-latency situations (over the internet) for machine learning applications, but can be used for any application requiring remote data access.

Contents:

- SFTP Backend
- User Configuration
- PyTorch Integration

# Indices and tables

- Index

- Module Index

- Search Page